pub struct TcpSocketIter<'a, 'd> { /* private fields */ }Expand description
Iterator over the TCP sockets of a Stack, returned by Stack::tcp_sockets.
Each item borrows the stack, so only one can exist at a time. That is why this is
not an Iterator and cannot be used in a for loop. Use while let:
let mut iter = stack.tcp_sockets();
while let Some((handle, item)) = iter.next() {
let _ = (handle, item.state());
}Implementations